# Python Qt Inkwell
A minimalistic dark theme for QT.

The projects provides a stylesheet as well as a few utility functions to apply
stylesheets to a QObject after passing them through a Sass compiler. it is no
where near complete, more of a shared stylesheet I use for the applications I
write.
